pub fn run_in_dir<I, T>(args: I, dir: &Path) -> Result<i32>Expand description
Parse explicit args and run against dir.
args must include argv[0] as first item.
Errors
Returns an error when project detection fails, command execution fails, or writing clap output fails.
Argument parsing/help/version flows are rendered by clap and returned as an exit code instead of terminating the host process.